package nl.rubend.zwemtimer

import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.IntrinsicSize
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.fillMaxHeight
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.width
import androidx.compose.material3.Button
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.getValue
import androidx.compose.runtime.key
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.setValue
import androidx.compose.ui.Modifier
import androidx.compose.ui.platform.LocalContext
import kotlinx.datetime.Clock

@Composable
fun items() {
    val store = Storage(LocalContext.current)
    val timerValue = remember { store.timers }
    var global by remember { store.global }
    var showDialog by remember { mutableStateOf(false) }
    if (showDialog) {
        ShowTextInputDialog {
            if (it != null) {
                timerValue.add(it)
                store.setTimers(timerValue)
            }
            showDialog = false
        }
    }
    Row {
        Button(onClick = {
            showDialog = true
        }) {
            Text("Add")
        }
        if (global == null) Button(onClick = {
            global = Clock.System.now()
            timerValue.forEach { it.startTime.value = global }
            store.setGlobal(global)
        }) {
            Text("Start all")
        } else confirmDialog("Reset global timer", "Reset global timer?") {
            if (it) {
                global = null
                store.setGlobal(global)
            }
        }
    }
    Row(modifier = Modifier.fillMaxHeight()) {
        timerValue.forEach { timer ->
            key(timer) {
                Column(
                    modifier = Modifier
                        .width(IntrinsicSize.Max)
                        .weight(1f)
                        .fillMaxHeight()
                ) {
                    var startTime by remember { timer.startTime }
                    Row {
                        confirmDialog("Remove", "Remove this timer?") {
                            if (it) {
                                timerValue.remove(timer)
                                store.setTimers(timerValue)
                            }
                        }
                        if (startTime == null) Button(onClick = {
                            startTime = Clock.System.now()
                            store.setTimers(timerValue)
                        }) {
                            Text("Start")
                        } else confirmDialog("Reset", "Reset this timer?") {
                            if (it) {
                                startTime = null
                                store.setTimers(timerValue)
                            }
                        }
                        if (startTime == null && global != null) confirmDialog(
                            "Join global timer",
                            "Join global timer?"
                        ) {
                            startTime = global
                            store.setTimers(timerValue)
                        }
                    }
                    Row(
                        modifier = Modifier
                            .fillMaxWidth()
                            .height(IntrinsicSize.Max)
                            .weight(1f)
                    ) {
                        composeTimer(timer)
                    }
                }
            }
        }
    }
}