package nl.rubend.zwemtimer

import android.content.Context
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.toMutableStateList
import com.google.gson.Gson
import com.google.gson.reflect.TypeToken
import kotlinx.datetime.Instant
import java.lang.reflect.Type

class Storage(context: Context) {
    private val gson: Gson = Gson()
    private val dataType: Type = object : TypeToken<ArrayList<TimerDTO>>() {}.type
    private val settings = context.getSharedPreferences("settings", Context.MODE_PRIVATE)
    val timers = gson.fromJson<List<TimerDTO>>(settings.getString("timers", "[]"), dataType).map { it.toTimer() }.toMutableStateList()
    private val globalNumber = settings.getLong("global", 0)
    private val globalNumberNullable = if(globalNumber==0L) null else globalNumber
    private val globalInstant = if(globalNumberNullable==null) null else Instant.fromEpochMilliseconds(globalNumberNullable)
    val global = mutableStateOf(globalInstant)
    fun setTimers(timers: List<Timer>)=settings.edit().putString("timers", gson.toJson(timers.map { it.toDto() })).apply()
    fun setGlobal(global: Instant?)=settings.edit().putLong("global", global?.toEpochMilliseconds() ?: 0).apply()
}