package nl.rubend.zwemtimer

import androidx.compose.foundation.background
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.fillMaxHeight
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.padding
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.LaunchedEffect
import androidx.compose.runtime.MutableState
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableIntStateOf
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.setValue
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.graphics.Color.Companion.Green
import androidx.compose.ui.text.PlatformTextStyle
import androidx.compose.ui.text.TextStyle
import androidx.compose.ui.unit.dp
import androidx.compose.ui.unit.sp
import kotlinx.coroutines.delay
import kotlinx.datetime.Clock
import kotlinx.datetime.Instant

data class Timer(
    val interval: Int,
    val amount: Int,
    val startTime: MutableState<Instant?>
) {
    fun toDto() = TimerDTO(interval, amount, startTime.value?.toEpochMilliseconds())
}

data class TimerDTO(
    val interval: Int,
    val amount: Int,
    var startTime: Long?,
) {
    fun toTimer() = Timer(
        interval,
        amount,
        mutableStateOf(if (startTime == null) null else Instant.fromEpochMilliseconds(startTime!!))
    )
}

@Composable
fun composeTimer(timer: Timer) {
    val startTime by remember { timer.startTime }
    var display by remember { mutableIntStateOf(0) }
    var secondsToNext by remember { mutableIntStateOf(0) }
    var difference by remember { mutableIntStateOf(0) }
    var showColor by remember { mutableStateOf(false) }
    var amountDone by remember { mutableIntStateOf(0) }
    var amountRemaining by remember { mutableIntStateOf(0) }
    LaunchedEffect(Unit) {
        while (true) {
            delay(500)
            if (startTime != null) {
                difference = Clock.System.now().minus(startTime!!).inWholeSeconds.toInt()
                secondsToNext = difference % timer.interval
                display = timer.interval - secondsToNext
                showColor = secondsToNext < 3
                amountDone = difference / timer.interval
                amountRemaining = timer.amount - amountDone
            }
        }
    }
    if (startTime != null) {
        Column(
            modifier = Modifier
                .fillMaxWidth()
                .fillMaxHeight()
                .background(
                    color = if (showColor) Green else Color.Unspecified,
                )
        ) {
            Text(fontSize = 100.sp, text = "$display", modifier = Modifier.padding(0.dp), style = TextStyle(
                platformStyle = PlatformTextStyle(
                    includeFontPadding = false
                )
            ))
            Text(
                modifier = Modifier.padding(0.dp),
                fontSize = 50.sp,
                text = "$amountDone/${timer.amount}\n($amountRemaining)",
                style = TextStyle(
                    platformStyle = PlatformTextStyle(
                        includeFontPadding = false
                    )
                )
            )
        }
    }
}