package nl.rubend.zwemtimer

import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.text.KeyboardOptions
import androidx.compose.material.icons.Icons
import androidx.compose.material.icons.filled.Close
import androidx.compose.material.icons.filled.Done
import androidx.compose.material3.AlertDialog
import androidx.compose.material3.Icon
import androidx.compose.material3.Text
import androidx.compose.material3.TextButton
import androidx.compose.material3.TextField
import androidx.compose.runtime.Composable
import androidx.compose.runtime.getValue
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.runtime.setValue
import androidx.compose.ui.Modifier
import androidx.compose.ui.text.input.ImeAction
import androidx.compose.ui.text.input.KeyboardType
import androidx.compose.ui.unit.dp

@Composable
fun ShowTextInputDialog(callback: (Timer?) -> Unit) {
    var secondsString by remember { mutableStateOf("") }
    var amountString by remember { mutableStateOf("") }
    AlertDialog(
        onDismissRequest = {
            callback(null)
        },
        title = {
            Text(text = "Config")
        },
        text = {
            Column {
                TextField(
                    value = secondsString,
                    onValueChange = {
                        secondsString = it
                    },
                    label = {
                        Text(text = "Seconds")
                    },
                    modifier = Modifier.padding(8.dp),
                    keyboardOptions = KeyboardOptions.Default.copy(
                        imeAction = ImeAction.Done,
                        keyboardType = KeyboardType.Number,
                    ),
                )
                TextField(
                    value = amountString,
                    onValueChange = {
                        amountString = it
                    },
                    label = {
                        Text(text = "Amount")
                    },
                    modifier = Modifier.padding(8.dp),
                    keyboardOptions = KeyboardOptions.Default.copy(
                        imeAction = ImeAction.Done,
                        keyboardType = KeyboardType.Number,
                    ),
                )
            }
        },
        confirmButton = {
            TextButton(
                onClick = {
                    callback(TimerDTO(
                        secondsString.toIntOrNull() ?: return@TextButton,
                        amountString.toIntOrNull() ?: return@TextButton,
                        null,
                    ).toTimer())
                }
            ) {
                Icon(imageVector = Icons.Default.Done, contentDescription = null)
                Text(text = "Done")
            }
        },
        dismissButton = {
            TextButton(
                onClick = {
                    callback(null)
                }
            ) {
                Icon(imageVector = Icons.Default.Close, contentDescription = null)
                Text(text = "Cancel")
            }
        },
    )
}